#
# spec file for package google-daemon
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           google-daemon
Version:        1.3.2
Release:        3.1
Summary:        VM management inside GCE
License:        Apache-2.0
Group:          System/Daemons
Url:            https://github.com/GoogleCloudPlatform/compute-image-packages
Source0:        %{name}-%{version}.tar.bz2
Source1:        google-address-manager.suse
Source2:        google-accounts-manager.suse
%if 0%{?suse_version} > 1140
BuildRequires:  systemd
%endif
%{?systemd_requires}
%if 0%{?suse_version} < 1140
Requires:       insserv
Requires:       sysvinit
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildArch:      noarch

%description
Google Daemon - A service that manages user accounts,
maintains ssh login keys, and syncs public endpoint IP addresses.

%prep
%setup -q

%build

%install
%{__mkdir} -p %{buildroot}/usr
%{__mkdir} -p %{buildroot}%{_sbindir}
cp -r usr/share %{buildroot}/usr
%if 0%{?suse_version} > 1140
    %{__mkdir} -p %{buildroot}/%{_unitdir}
    cp usr/lib/systemd/system/google-address-manager.service %{buildroot}/%{_unitdir}
    cp usr/lib/systemd/system/google-accounts-manager.service %{buildroot}/%{_unitdir}
    pushd %{buildroot}%{_sbindir}
    ln -s service rcgoogle-address-manager
    ln -s service rcgoogle-accounts-manager
    popd
%else
  %{__mkdir} -p %{buildroot}/%{_initddir}
  cp %{SOURCE1} %{buildroot}/%{_initddir}/google-address-manager
  cp %{SOURCE2} %{buildroot}/%{_initddir}/google-accounts-manager
  ln -s ../../%{_initrddir}/google-address-manager %{buildroot}%{_sbindir}/rcgoogle-address-manager
  ln -s ../../%{_initrddir}/google-accounts-manager %{buildroot}%{_sbindir}/rcgoogle-accounts-manager
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?suse_version} > 1140
    %service_del_preun google-address-manager.service
    %service_del_preun google-accounts-manager.service
%else
    %stop_on_removal
%endif

%pre
%if 0%{?suse_version} > 1140
    %service_add_pre google-address-manager.service
    %service_add_pre google-accounts-manager.service
%endif

%post
%if 0%{?suse_version} > 1140
    %service_add_post google-address-manager.service
    %service_add_post google-accounts-manager.service
%endif

%postun
%if 0%{?suse_version} > 1140
    %service_del_postun google-address-manager.service
    %service_del_postun google-accounts-manager.service
%else
    %insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{_datadir}/google/google_daemon/*
%{_sbindir}/rcgoogle-address-manager
%{_sbindir}/rcgoogle-accounts-manager
%dir %{_datadir}/google
%dir %{_datadir}/google/google_daemon
%if 0%{?suse_version} > 1140
%{_unitdir}/google-address-manager.service
%{_unitdir}/google-accounts-manager.service
%else
%attr(0755,root,root) %{_initddir}/google-address-manager
%attr(0755,root,root) %{_initddir}/google-accounts-manager
%endif

%changelog
* Sat Feb 13 2016 rjschwei@suse.com
- Update to version 1.3.2 (bsc#966582, bsc 966583)
  + We are deprecating "sshKeys" in instance metadata.
  + Support adding SSH keys to "ssh-keys" project metadata.
  + Support adding SSH keys to "ssh-keys" instance metadata.
  + Support "block-project-ssh-keys" in instance metadata.
  + Set value to "true" to block project SSH key metadata.
  + Using "sshKeys" in instance metadata will block project SSH keys.
* Thu Jan 28 2016 rjschwei@suse.com
- Update to version 1.3.1 (bsc#963879,bsc#963880)
  + Refactored accounts daemon.
  + Support "ssh-keys" in project metadata in addition to "sshKeys".
  + Support instance "override-ssh-keys" in addition to "sshKeys"
  + Support "additional-ssh-keys" in instance metadata.
* Mon Nov 23 2015 rjschwei@suse.com
- Update to version 1.2.10 (bsc#956339,bsc#956340)
  + Improved documentation
  + Refactored and improved script that runs on boot
- Version consistency with google-startup-scripts
* Mon Aug  3 2015 jgleissner@suse.com
- Update to version 1.2.7 (bnc#940190)
  + Fix check for gcua
  + Preventing the accounts manager from starting if GCUA is
    installed.
  + Remove temp files when move operation fails
  + Fix string formatting.
  + Documentation should point to gcloud compute instead of the
    deprecated gcutil.
  + Use /bin/ip instead of /sbin/ip
  + Google clock sync manager to sync the system clock when a migration
    occurs. Fix white space in existing daemons to be consistent.
* Wed Mar 11 2015 rjschwei@suse.com
- Update to version 1.2.4 (bnc#921732)
  + Version consistency with startup scripts
  + Reduced SSH key-related console spam.
* Fri Nov 14 2014 rschweikert@suse.com
- Update to version 1.1.9  bnc#905573
    + Generalize SSH host key regeneration to handle all types which are
    already present in the image
    + Further reduce excessive default logging to console
    + Never add SSH keys for system accounts with /sbin/nologin as shell
    + Add rc* links for distributions newer than 1140
* Tue Oct 14 2014 rschweikert@suse.com
- Fix .suse init script, remove run level 4 setting to avoid warning
* Mon Jul 28 2014 rschweikert@suse.com
- Update to version 1.1.5
  + Lowered some logging level to avoid spamming console log
  + Added client timeout to metadata hanging request
* Tue Jul  1 2014 rschweikert@suse.com
- Update to version 1.1.4
  + Fix ssh keys files being emptied when disk is full.
  + Remove users' keys when they are removed from metadata.
  + Support setting an expiration timestamp for users' keys.
* Wed Jun  4 2014 rschweikert@suse.com
- Update to version 1.1.3
  + no upstream change log, nor decent commit messages that separate
    changes to this code bases vs. other code in the same repo
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Wed Feb 19 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
- Use upstream version 1.1.1, additional changes to previous:
  + Syncs ssh keys immediately instead of on per minute intervals.
  + Improved systemd integration.
  + Fixed data corruption bug.
* Thu Dec  5 2013 rschweikert@suse.com
- update to 1.1.1
  + carries changes not yet merged upstream for systemd integration
  + no change log provided
* Wed Nov 20 2013 rschweikert@suse.com
- update to 1.0.10 rc2
- fix systemd unit file
* Wed Nov  6 2013 rschweikert@suse.com
- integrate new startup script for account manager-
* Thu Oct 31 2013 rschweikert@suse.com
- update to 1.0.9 pre-release of 1.0.10
- fix typo in init script
- fix permission issue with init script
* Wed Oct 30 2013 rschweikert@suse.com
- update to 1.0.7.1
  + add .1 version as the upstream 1.0.7 tarball does not contain the
    systemd bits, although the git repo has the bits
- add SUSE specific systemV init script
  + the upstream script is almost generic but assumes some Debian
    specifc stuff
- some spec file clean up
* Fri Oct 11 2013 rschweikert@suse.com
- fix build issue for 12.2 location of systemd still in / not /usr
* Thu Oct 10 2013 rschweikert@suse.com
- add the license to the tarball
- fix the mkdir command
* Thu Oct 10 2013 rschweikert@suse.com
- push to 1.0.6.2
  + minor fixes to systemd integration
* Tue Oct  8 2013 rschweikert@suse.com
- Initial build
